@@ -6,11 +6,11 @@
  * /______/ //______/ //_/ //_____/\ /_/ //_/ //_/ //_/ //_/ /|_/ /
  * \______\/ \______\/ \_\/ \_____\/ \_\/ \_\/ \_\/ \_\/ \_\/ \_\/
  *
- * Copyright (c) 2004 - 2008 Olof Naessn and Per Larsson
+ * Copyright (c) 2004 - 2008 Olof Naessén and Per Larsson
  *
  *
  * Per Larsson a.k.a finalman
- * Olof Naessn a.k.a jansem/yakslem
+ * Olof Naessén a.k.a jansem/yakslem
  *
  * Visit: http://guichan.sourceforge.net
  *
@@ -113,11 +113,11 @@ namespace gcn
     void  HGEInput::_pollInput()
     {
         hgeInputEvent ie;
-    
-        mHGE->Input_GetEvent(&ie);
-        
+
+        while (mHGE->Input_GetEvent(&ie)
+            pollKeyInput(ie);
+
         pollMouseInput();
-        pollKeyInput(ie);
     }
 
     void  HGEInput::pollMouseInput()
